==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebColumnMovingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEventArgsDetailDescription } from "./WebColumnMovingEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnMovingEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnMovingEventArgsDetailDescriptionMetadata, _super);
    function WebColumnMovingEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnMovingEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnMovingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingEventArgsDetailDescriptionMetadata.c(WebColumnMovingEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebColumnMovingEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebColumnMovingEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnMovingEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnMovingEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Source", "ExportedType:WebColumn");
        a.item("Cancel", "Boolean");
    };
    WebColumnMovingEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnMovingEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebColumnMovingEventArgsDetail", function () { return new WebColumnMovingEventArgsDetailDescription(); });
        a.z("WebColumnMovingEventArgsDetail", WebColumnMovingEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnMovingEventArgsDetailDescriptionMetadata.$t = markType(WebColumnMovingEventArgsDetailDescriptionMetadata, 'WebColumnMovingEventArgsDetailDescriptionMetadata');
    WebColumnMovingEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnMovingEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebColumnMovingEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnMovingEventArgsDetailDescription } from "./WebColumnMovingEventArgsDetailDescription";
/**
 * @hidden
 */
var WebColumnMovingEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebColumnMovingEventArgsDetailDescriptionMetadata, _super);
    function WebColumnMovingEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebColumnMovingEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebColumnMovingEventArgsDetailDescriptionMetadata.a == null) {
            WebColumnMovingEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebColumnMovingEventArgsDetailDescriptionMetadata.c(WebColumnMovingEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebColumnMovingEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebColumnMovingEventArgsDetailDescriptionMetadata.a);
        WebColumnDescriptionMetadata.d(a);
    };
    WebColumnMovingEventArgsDetailDescriptionMetadata.c = function (a) {
        WebBaseEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:ColumnMovingEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Source", "ExportedType:WebColumn");
        a.item("Cancel", "Boolean");
    };
    WebColumnMovingEventArgsDetailDescriptionMetadata.d = function (a) {
        WebColumnMovingEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebColumnMovingEventArgsDetail", function () { return new WebColumnMovingEventArgsDetailDescription(); });
        a.ab("WebColumnMovingEventArgsDetail", WebColumnMovingEventArgsDetailDescriptionMetadata.a);
    };
    WebColumnMovingEventArgsDetailDescriptionMetadata.$t = markType(WebColumnMovingEventArgsDetailDescriptionMetadata, 'WebColumnMovingEventArgsDetailDescriptionMetadata');
    WebColumnMovingEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnMovingEventArgsDetailDescriptionMetadata;
}(Base));
export { WebColumnMovingEventArgsDetailDescriptionMetadata };
